@@ -1,8 +1,16 @@
 import os
-import streamlit.components.v1 as components
-from typing import List,Set
+import csv
 import json
 
+from operator import itemgetter
+import streamlit.components.v1 as components
+from typing import List, Set
+from streamlit_agraph import TripleStore
+
+import networkx as nx
+from networkx.algorithms import community
+
+import streamlit as st
 # python setup.py sdist bdist_wheel
 # twine upload  dist/*
 
@@ -121,6 +129,34 @@ class TripleStore:
 # def parse_node(*args):
 #  nodes_data = [{"id": f"{node}"} for node in nodes]
 
+class GraphAlgos:
+  def __init__(self, store:TripleStore):
+    self.node_names = [n.id for n in store.nodes_set]
+    self.edges = [(e.source, e.target) for e in store.edges_set]
+    G = nx.Graph()  # Initialize a Graph object
+    G.add_nodes_from(self.node_names)  # Add nodes to the Graph
+    G.add_edges_from(self.edges)  # Add edges to the Graph
+
+    self.G = G
+    self.density = self.density()
+    # self.shortest_path() = self.shortest_path()
+    # self.find_communities = self.find_communities()
+    pass
+
+  def density(self):
+    return nx.density(self.G)
+
+  def shortest_path(self, source, target):
+    try:
+      sp = nx.shortest_path(self.G, source=source, target=target)
+    except nx.NetworkXNoPath:
+      return  []
+    else:
+      return sp
+  def find_communities(self) -> str:
+    # print(nx.info(G))  # Print information about the Graph
+    return "hello community"
+
 def agraph(nodes, edges, config):
 
     nodes_data = [ node.to_dict() for node in nodes]
